@@ -1,3 +1,6 @@
 # Update namespace to allow easier imports such as "from dokusu import Sudoku"
 from . import core
 from .core import *
+
+from . import rules
+from .rules import *
